import{Q as i,br as m,c as n,am as r,Z as l,B as u,S as c,a4 as h}from"./index-DxANhO1k.js";import{I as f}from"./ItemsListing-BOmO3Do4.js";import"./MediaItemThumb-CFMeVmOC.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-DOvPB9zZ.js";import"./VBtn-BKDLm-Pz.js";import"./VCheckbox-DjCmGFGI.js";import"./VCheckboxBtn-CJJKU0Jh.js";import"./PanelviewItemCompact-CK0jmgCV.js";import"./VSpacer-DFaVs3iZ.js";/* empty css              */import"./Container-BWpo4_AD.js";import"./VContainer-Dt14Bz2c.js";import"./Toolbar-C8FmMECG.js";import"./VToolbar-CF24PT7R.js";import"./VTextField-Dsv55ZTU.js";import"./VInfiniteScroll-BUbVsPar.js";import"./layout-DxBddAEz.js";import"./VRow-DUKgywhZ.js";import"./VVirtualScroll-HpbJdiAg.js";import"./VAlert-C_Jv1M-3.js";const D=i({__name:"BrowseView",props:{path:{}},setup(a){const t=a,{t:e}=m(),s=n(()=>!t.path||t.path=="root"?e("browse"):r("bp6")?e("browse")+" | "+t.path:r("bp3")?t.path:e("browse")),p=async function(o){return await h.browse(t.path)};return(o,w)=>(c(),l("section",null,[u(f,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"show-select-button":!!(o.path&&o.path!="root"),"load-items":p,"sort-keys":["original","name","name_desc"],title:s.value,path:o.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["show-select-button","title","path"])]))}});export{D as default};
